@@ -4,6 +4,9 @@ from flockai.interfaces.drone import IDrone
 
 
 class AutopilotControlledDrone(IDrone, abc.ABC):
+    def __init__(self):
+        self.flight_plan = [2, 3, 1, 4, 6]
+
     def set_flight_plan(self, plan):
         pass
 
@@ -21,6 +24,5 @@ class AutopilotControlledDrone(IDrone, abc.ABC):
         roll_disturbance = 0
         pitch_disturbance = 2
         yaw_disturbance = 0
-        print(roll_disturbance, pitch_disturbance, yaw_disturbance)
 
         return roll_disturbance, pitch_disturbance, yaw_disturbance
